First Name | Full Name | Active | Emails | Status | Created | Due Date | Number
--- | --- | --- | --- | --- | --- | --- | ---
fn004 | fn004 ln004 | Yes | email004@example.com, email004@gmail.com |  | 02/22/2012 10:04 AM | 02/04/2012 | 2.13
fn002 | fn002 ln002 | Yes | email002@example.com, email002@gmail.com | pending |  |  | 2.13
fn001 | fn001 ln001 | Yes | email001@example.com, email001@gmail.com | in process | 02/22/2012 10:01 AM | 02/01/2012 | 2.13